16.152. cdist-type__user_groups(7) — cdist 6.5.4 documentation

# 16.152. cdist-type__user_groups(7)

## 16.152.1. NAME

cdist-type__user_groups - Manage user groups

## 16.152.2. DESCRIPTION

Adds or removes a user from one or more groups.

## 16.152.3. REQUIRED PARAMETERS

group
  the group to which this user should be added or removed. Can be specified multiple times.

## 16.152.4. OPTIONAL PARAMETERS

user
  the name of the user. Defaults to object_id
state
  absent or present. Defaults to present.

## 16.152.5. EXAMPLES

    __user_groups nginx --group webuser1 --group webuser2

    # remove user nginx from groups webuser2
    __user_groups nginx-webuser2 --user nginx \
       --group webuser2 --state absent

## 16.152.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 16.152.7. COPYING

Copyright (C) 2012 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.